This function provides plots to see the typical transition from undeveloped through fully exploited, to collapsed for each resources as per the criteria used by Pauly et al (2008) to interpret the status of fishery resource
SSplots_pauly(data,lower.lt,upper.lt, tsplots,MA)This function returns two plots one with "number of stocks by status" and the other one is "catch by stock status" apart from the time seriers plots.
dataset
lower limit
upper limit
time series plot
moving average
**Status of fishery** **Criterion Applied**
Undeveloped: Year< max landings AND landings < 10 percent of max value
Developing: Year < max landings AND landings is between 10-50 percent of max value
Fully exploited: Landings > 50 percent of max value
Overexploited: Year > max landings AND landings is between 10-50 percent of max value
Collapsed: Year > max landings AND landings< 10 percent of max value
1) Grainger RJR and Garcia S (1996) Chronicles of marine fisheries landings (1950-1994): trend analysis and fisheries potential. FAO Fisheries Technical Paper 359, 51 p.
2) Kristin Kleisner and Daniel Pauly (2015) Stock-Status Plots (SSPs), https://www.seaaroundus.org/stock-status-plots-method/ (accessed on 28.02.2023)
3) Pauly D, Alder J, Booth S, Cheung WWL, Christensen V, Close C, Sumaila UR, Swartz W, Tavakolie A, Watson R and Zeller D (2008) Fisheries in Large Marine Ecosystems: Descriptions and Diagnoses. pp. 23-40 In: Sherman K and Hempel G (eds.), The UNEP Large Marine Ecosystem Report: a Perspective on Changing Conditions in LMEs of the World’s Regional Seas. UNEP Regional Seas Reports and Studies No. 182, Nairobi.
4) Sherman K and Hempel G, editors (2008) The UNEP Large Marine Ecosystem report: a Perspective on Changing Conditions in LMEs of the World's Regional Seas. UNEP Regional Seas Reports and Studies No. 182, United Nations Environment Programme, Nairobi. 852 p.
library (SSplots)
data(SampleData)
SSplots_pauly(data=SampleData,lower.lt=10,upper.lt=50, tsplots=FALSE,MA=FALSE)
Run the code above in your browser using DataLab